;;; custom-load.el --- automatically extracted custom dependencies

;;; Code:

(autoload 'custom-add-loads "cus-load")

(custom-add-loads 'fortran-indent '("fortran"))
(custom-add-loads 'f90 '("f90"))
(custom-add-loads 'fortran-comment '("fortran"))
(custom-add-loads 'f90-indent '("f90"))
(custom-add-loads 'fortran '("fortran"))
(custom-add-loads 'languages '("f90" "fortran"))

;;; custom-load.el ends here
